<?php

namespace Drupal\monarch_linkit\Plugin\Linkit\Matcher;

use Drupal\linkit\Plugin\Linkit\Matcher\EntityMatcher;
use Drupal\file\Entity\File;

/**
 * Media URL matcher for media entities.
 *
 * Matches the default media matcher (EntityMatcher), but returns the
 * source URL of the media entity instead of the URL for the entity
 * itself.
 *
 * @Matcher(
 *   id = "entity:media_url",
 *   target_entity = "media",
 *   label = @Translation("Media URL"),
 *   provider = "media"
 * )
 */
class MediaSourceMatcher extends EntityMatcher {

  /**
   * {@inheritdoc}
   */
  protected function buildPath($entity) {
    // This plugin targets media entities, so validation not really needed.
    $source = $entity->getSource();

    if (in_array($source->getPluginId(), ['image', 'file'], TRUE)) {
      /*
       * Both of these media sources use file id under the hood. It may be
       * worth converting this to a db_query to avoid loading the entire
       * file entity and add flexibility in grabbing those urls.
       */
      $source_value = $source->getSourceFieldValue($entity);
      $file_entity = File::load($source_value);
      return file_url_transform_relative(file_create_url($file_entity->getFileUri()));
    }

    return $entity->toUrl()->toString();
  }

}
